@@ -1,9 +1,11 @@
 #ifndef SIMDJSON_JSONIOUTIL_H
 #define SIMDJSON_JSONIOUTIL_H
 
-#include "simdjson/common_defs.h"
+#include "simdjson/base.h"
 #include "simdjson/padded_string.h"
 
+#include "simdjson/padded_string-inl.h"
+
 namespace simdjson {
 
 #if SIMDJSON_EXCEPTIONS
